@@ -20,6 +20,8 @@ import textwrap
 from argparse import ArgumentDefaultsHelpFormatter, ArgumentParser, RawDescriptionHelpFormatter
 from distutils.util import strtobool
 
+import tabulate
+
 import fastoad
 from fastoad import notebooks
 from fastoad._utils.resource_management.copy import copy_resource_folder
@@ -91,7 +93,12 @@ class Main:
     @staticmethod
     def _list_variables(args):
         """Prints list of system outputs."""
-        api.list_variables(args.conf_file, out=args.out_file, overwrite=args.force)
+        api.list_variables(
+            args.conf_file,
+            out=args.out_file,
+            overwrite=args.force,
+            tablefmt=args.format,
+        )
 
     @staticmethod
     def _write_n2(args):
@@ -171,7 +178,7 @@ class Main:
         print("")
         print("Notebooks have been created in %s" % target_path)
         print("You may now run Jupyter with:")
-        print('   jupyter notebook "%s"' % target_path)
+        print('   jupyter lab "%s"' % target_path)
 
     # UTILITIES ====================================================================================
 
@@ -222,7 +229,7 @@ class Main:
         )
         parser_gen_conf.help = parser_gen_conf.description
         parser_gen_conf.add_argument(
-            "conf_file", type=str, help="the name of configuration file to be written",
+            "conf_file", type=str, help="the name of configuration file to be written"
         )
         self._add_overwrite_argument(parser_gen_conf)
         parser_gen_conf.set_defaults(func=self._generate_conf_file)
@@ -252,10 +259,10 @@ class Main:
             """\
             Examples:
             ---------
-            # For the problem defined in conf_file.yml, generates the input file with default 
+            # For the problem defined in conf_file.yml, generates the input file with default
             # values (when default values are defined):
                 %(prog)s conf_file.yml
-            
+
             # Same as above, except that values are taken from some_file.xml when possible:
                 %(prog)s conf_file.yml some_file.xml
 
@@ -295,6 +302,15 @@ class Main:
         self._add_conf_file_argument(parser_list_variables)
         self._add_output_file_argument(parser_list_variables)
         self._add_overwrite_argument(parser_list_variables)
+        parser_list_variables.add_argument(
+            "--format",
+            nargs="?",
+            default="grid",
+            help="format of the list. Available options are "
+            f"{['var_desc'] + tabulate.tabulate_formats}. "
+            '"var_desc" is the variable_descriptions.txt format. Other formats are part of the '
+            "tabulate package. (default: %(default)s)",
+        )
         parser_list_variables.set_defaults(func=self._list_variables)
 
         # sub-command for writing N2 diagram -------------------------------------------------------
@@ -313,7 +329,7 @@ class Main:
         )
         parser_n2.set_defaults(func=self._write_n2)
 
-        # sub-command for writing XDSM diagram -------------------------------------------------------
+        # sub-command for writing XDSM diagram -----------------------------------------------------
         parser_xdsm = subparsers.add_parser(
             "xdsm",
             help="Writes the XDSM diagram of the problem",
@@ -328,7 +344,7 @@ class Main:
             help="path of file to be written (default: %(default)s)",
         )
         parser_xdsm.add_argument(
-            "--depth", nargs="?", default=2, help="Depth of analysis", type=int,
+            "--depth", nargs="?", default=2, help="Depth of analysis", type=int
         )
         parser_xdsm.add_argument(
             "--server",
@@ -341,7 +357,7 @@ class Main:
 
         # sub-command for running the model --------------------------------------------------------
         parser_run_model = subparsers.add_parser(
-            "eval", help="Runs the analysis", description="Runs the analysis",
+            "eval", help="Runs the analysis", description="Runs the analysis"
         )
         self._add_conf_file_argument(parser_run_model)
         self._add_overwrite_argument(parser_run_model)
@@ -349,7 +365,7 @@ class Main:
 
         # sub-command for running the driver -------------------------------------------------------
         parser_run_driver = subparsers.add_parser(
-            "optim", help="Runs the optimization", description="Runs the optimization",
+            "optim", help="Runs the optimization", description="Runs the optimization"
         )
         self._add_conf_file_argument(parser_run_driver)
         self._add_overwrite_argument(parser_run_driver)
