@@ -22,7 +22,7 @@ from .constants import SERVICE_FLIGHT_CONTROLS_MASS
 
 
 @RegisterSubmodel(
-    SERVICE_FLIGHT_CONTROLS_MASS, "fastoad.submodel.weight.mass.airframe.flight_control.legacy",
+    SERVICE_FLIGHT_CONTROLS_MASS, "fastoad.submodel.weight.mass.airframe.flight_control.legacy"
 )
 class FlightControlsWeight(om.ExplicitComponent):
     """
