@@ -163,14 +163,15 @@ class Variable(Hashable):
         variable_descriptions = None
         description_file = None
 
-        if pth.isdir(file_parent):
-            file_path = pth.join(file_parent, DESCRIPTION_FILENAME)
-            if pth.isfile(file_path):
-                description_file = open(file_path)
-        else:
-            # Then it is a module name
-            if DESCRIPTION_FILENAME in contents(file_parent):
-                description_file = open_text(file_parent, DESCRIPTION_FILENAME)
+        if file_parent:
+            if pth.isdir(file_parent):
+                file_path = pth.join(file_parent, DESCRIPTION_FILENAME)
+                if pth.isfile(file_path):
+                    description_file = open(file_path)
+            else:
+                # Then it is a module name
+                if DESCRIPTION_FILENAME in contents(file_parent):
+                    description_file = open_text(file_parent, DESCRIPTION_FILENAME)
 
         if description_file is not None:
             try:
@@ -455,7 +456,7 @@ class VariableList(list):
 
     @classmethod
     def from_dict(
-        cls, var_dict: Union[Mapping[str, dict], Iterable[Tuple[str, dict]]],
+        cls, var_dict: Union[Mapping[str, dict], Iterable[Tuple[str, dict]]]
     ) -> "VariableList":
         """
         Creates a VariableList instance from a dict-like object.
@@ -504,8 +505,8 @@ class VariableList(list):
         """
         Creates a VariableList instance from a pandas DataFrame instance.
 
-        The DataFrame instance is expected to have column names "name" + some keys among the ones given by
-        :meth:`Variable.get_openmdao_keys`.
+        The DataFrame instance is expected to have column names "name" + some keys among the ones
+        given by :meth:`Variable.get_openmdao_keys`.
 
         :param df: a DataFrame instance
         :return: a VariableList instance
@@ -740,7 +741,7 @@ class VariableList(list):
         )
 
         def _add_outputs(unconnected_names):
-            """ Fills ivc with data associated to each provided var"""
+            """Fills ivc with data associated to each provided var"""
             for abs_name in unconnected_names:
                 prom_name = io_metadata[abs_name]["prom_name"]
                 if prom_name not in processed_prom_names:
